LatticeStripe.Subscription.PauseCollection (LatticeStripe v1.1.0)

Copy Markdown View Source

Represents the pause_collection nested object on a Stripe Subscription.

When set, Stripe pauses automatic invoice collection for the subscription with the given behavior:

  • "keep_as_draft" — invoices are created but left as drafts
  • "mark_uncollectible" — invoices are created and marked uncollectible
  • "void" — invoices are created and immediately voided

Optionally, resumes_at is a Unix timestamp at which collection will automatically resume.

See Stripe Subscription API.

Summary

Types

t()

Pause collection settings for a Stripe Subscription.

Functions

Converts a decoded Stripe API map to a %PauseCollection{} struct.

Types

t()

@type t() :: %LatticeStripe.Subscription.PauseCollection{
  behavior: String.t() | nil,
  extra: map(),
  resumes_at: integer() | nil
}

Pause collection settings for a Stripe Subscription.

Functions

from_map(map)

@spec from_map(map() | nil) :: t() | nil

Converts a decoded Stripe API map to a %PauseCollection{} struct.

Returns nil when given nil.