Represents the pause_collection nested object on a Stripe Subscription.
When set, Stripe pauses automatic invoice collection for the subscription
with the given behavior:
"keep_as_draft"— invoices are created but left as drafts"mark_uncollectible"— invoices are created and marked uncollectible"void"— invoices are created and immediately voided
Optionally, resumes_at is a Unix timestamp at which collection will
automatically resume.
Summary
Functions
Converts a decoded Stripe API map to a %PauseCollection{} struct.